ExpectedError

Enum ExpectedError 

pub enum ExpectedError {
    Separator {
        at: Option<usize>,
        got: Option<char>,
    },
    EndOfInput {
        at: Option<usize>,
        got: char,
    },
    Numeric {
        at: Option<usize>,
        got: Option<char>,
    },
}
An error type for faults relating to parsing and expecting a certain type of token.

Variants



Separator

When this error variant is returned, the . token, i.e. the separator, was expected, but a different token was present. The got field shows the token read.

Fields

at: Option<usize>

Place where the token was expected.

May be None if the respective parser does not store the index.

got: Option<char>

Token found instead, or None if we unexpectedly got the end-of-input.



EndOfInput

When this error variant is returned, the parser expected that no more tokens should be present, but instead 1 or more additional tokens were not parsed yet.

The got field contains the next token received, where it expected none to be remaining.

Fields

at: Option<usize>

Place where the end-of-input was expected.

May be None if the respective parser does not store the index.

got: char

Character found at the expected end-of-input.



Numeric

When this error variant is returned, a numeric token was expected, but a different token was present.

The got field shows the token read.

Fields

at: Option<usize>

Place where the token was expected.

May be None if the respective parser does not store the index.

got: Option<char>

Token found instead, or None if we unexpectedly got the end-of-input.